Aude has uploaded a new change for review.
https://gerrit.wikimedia.org/r/116096
Change subject: Add missing recent changes show/hide messages
......................................................................
Add missing recent changes show/hide messages
Bug: 62050
Change-Id: If9810753f929d3cc8918938ae9a11c9578525a17
---
M client/WikibaseClient.i18n.php
1 file changed, 15 insertions(+), 1 deletion(-)
git pull ssh://gerrit.wikimedia.org:29418/mediawiki/extensions/Wikibase
refs/changes/96/116096/1
diff --git a/client/WikibaseClient.i18n.php b/client/WikibaseClient.i18n.php
index 84fa167..2ee3678 100644
--- a/client/WikibaseClient.i18n.php
+++ b/client/WikibaseClient.i18n.php
@@ -55,6 +55,8 @@
'wikibase-property-notfound' => '$1 property not found.',
'wikibase-property-notsupportedyet' => 'Wikibase does not yet support
property type for $1 property.',
'wikibase-rc-hide-wikidata' => '$1 Wikidata',
+ 'wikibase-rc-hide-wikidata-hide' => 'Hide',
+ 'wikibase-rc-hide-wikidata-show' => 'Show',
'wikibase-rc-show-wikidata-pref' => 'Show Wikidata edits in recent
changes',
'wikibase-rc-wikibase-edit-letter' => 'D',
'wikibase-rc-wikibase-edit-title' => 'Wikidata edit',
@@ -164,7 +166,19 @@
'wikibase-rc-hide-wikidata' => 'This refers to a toggle to hide or show
edits (revisions) that come from Wikidata. If set to "hide", it hides edits
made to the connected item in the Wikidata repository.
Parameters:
* $1 - a link with the text {{msg-mw|show}} or {{msg-mw|hide}}',
{{msg-mw|wikibase-rc-hide-wikidata-hide}}',
+ 'wikibase-rc-hide-wikidata-hide' => '{{doc-actionlink}}
+Option text in [[Special:RecentChanges]] in conjunction with
{{msg-mw|wikibase-rc-hide-wikidata}}.
+
+See also:
+* {{msg-mw|wikibase-rc-hide-wikidata-show}}
+{{Identical|Hide}}',
+ 'wikibase-rc-hide-wikidata-show' => '{{doc-actionlink}}
+Option text in [[Special:RecentChanges]] in conjunction with
{{msg-mw|wikibase-rc-hide-wikidata}}.
+
+See also:
+* {{msg-mw|wikibase-rc-hide-wikidata-hide}}
+{{Identical|Show}}',
'wikibase-rc-show-wikidata-pref' => 'Option in the recent changes
section of preferences to show wikibase changes by default in recent changes.',
'wikibase-rc-wikibase-edit-letter' => "Very short form of \"'''wikidata
@@ -164,7 +166,19 @@
made to the connected item in the Wikidata repository.
Parameters:
-* $1 - a link with the text {{msg-mw|show}} or {{msg-mw|hide}}',
+* $1 - a link with the text {{msg-mw|wikibase-rc-hide-wikidata-show}} or
{{msg-mw|wikibase-rc-hide-wikidata-hide}}',
edit'''\". Used in [[Special:RecentChanges]] and [[Special:Watchlist]].
--
To view, visit https://gerrit.wikimedia.org/r/116096
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings
Gerrit-MessageType: newchange
Gerrit-Change-Id: If9810753f929d3cc8918938ae9a11c9578525a17
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/extensions/Wikibase
Gerrit-Branch: master
Gerrit-Owner: Aude <[email protected]>
_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits